@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -33,7 +32,7 @@
 """|UDM| module for |DNS| aliases (CNAME)"""
 
 import re
-from typing import Match  # noqa: F401
+from re import Match  # noqa: F401
 
 from ldap.filter import filter_format
 
@@ -41,7 +40,7 @@ import univention.admin.filter
 import univention.admin.handlers
 import univention.admin.handlers.dns.forward_zone
 import univention.admin.localization
-from univention.admin.handlers.dns import DNSBase, is_dns, stripDot  # noqa: F401
+from univention.admin.handlers.dns import DNSBase, is_dns, stripDot
 from univention.admin.layout import Group, Tab
 
 
