@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -87,7 +86,7 @@ class object(univention.admin.handlers.simpleLdap):
     module = module
 
     def _ldap_dn(self):
-        dn = ldap.dn.str2dn(super(object, self)._ldap_dn())
+        dn = ldap.dn.str2dn(super()._ldap_dn())
         dn[0] = [(dn[0][0][0], dn[0][0][1].lower(), dn[0][0][2])]
         return ldap.dn.dn2str(dn)
 
