@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -189,7 +188,7 @@ class object(univention.admin.handlers.simpleLdap):
     module = module
 
     def _ldap_pre_modify(self):
-        super(object, self)._ldap_pre_modify()
+        super()._ldap_pre_modify()
         diff_keys = [key for key in self.info.keys() if self.info.get(key) != self.oldinfo.get(key) and key not in ('active', 'appidentifier')]
         if not diff_keys:  # check for trivial change
             return
@@ -217,7 +216,7 @@ class object(univention.admin.handlers.simpleLdap):
                     old_dict = dict(old_value)
                     new_dict = dict(new_value)
                     for tag, old_mo_data_base64 in old_dict.items():
-                        ldap_attribute = ''.join((ldap_attr, tag))
+                        ldap_attribute = f'{ldap_attr}{tag}'
                         new_mo_data_base64 = new_dict.get(tag)
                         if not new_mo_data_base64:  # property value has been removed
                             old_mo_data_binary = univention.admin.mapping.mapBase64(old_mo_data_base64)
@@ -228,7 +227,7 @@ class object(univention.admin.handlers.simpleLdap):
                                 new_mo_data_binary = univention.admin.mapping.mapBase64(new_mo_data_base64)
                                 modlist.append((ldap_attribute, old_mo_data_binary, new_mo_data_binary))
                     for tag, new_mo_data_base64 in new_dict.items():
-                        ldap_attribute = ''.join((ldap_attr, tag))
+                        ldap_attribute = f'{ldap_attr}{tag}'
                         if not old_dict.get(tag):  # property value has been added
                             new_mo_data_binary = univention.admin.mapping.mapBase64(new_mo_data_base64)
                             modlist.append((ldap_attribute, None, new_mo_data_binary))
