@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -113,7 +112,7 @@ class object(univention.admin.handlers.simpleLdap):
     default_containers_attribute_name = 'printers'
 
     def _ldap_pre_create(self):
-        super(object, self)._ldap_pre_create()
+        super()._ldap_pre_create()
         self.is_valid_printer_object()  # check all members
 
     def _ldap_modlist(self):  # check for membership in a quota-printerclass
@@ -122,7 +121,7 @@ class object(univention.admin.handlers.simpleLdap):
         return univention.admin.handlers.simpleLdap._ldap_modlist(self)
 
     def _ldap_pre_remove(self):  # check for last member in printerclass on same spoolhost
-        super(object, self)._ldap_pre_remove()
+        super()._ldap_pre_remove()
         printergroups_filter = '(&(objectClass=univentionPrinterGroup)(|%s))' % (''.join(filter_format('(univentionPrinterSpoolHost=%s)', [x]) for x in self.info['spoolHost']))
         rm_attrib = []
         for pg_dn, member_list in self.lo.search(filter=printergroups_filter, attr=['univentionPrinterGroupMember', 'cn']):
