@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -39,9 +38,10 @@ import getopt
 import os
 import subprocess
 import sys
+from collections.abc import Sequence  # noqa: F401
 from ipaddress import IPv4Address, IPv4Network
 from logging import getLogger
-from typing import IO, Any, Dict, List, Optional, Sequence, Tuple, TypeVar, Union, overload  # noqa: F401
+from typing import TypeVar, overload
 
 
 try:
@@ -671,7 +671,7 @@ def _doit(
         raise OperationFailed()
 
 
-class CLI(object):
+class CLI:
 
     def __init__(
         self,
@@ -1012,9 +1012,9 @@ class CLI(object):
                         # TODO: sharedsubnet_module = univention.admin.modules._get('dhcp/sharedsubnet')
                         ips = object['fixedaddress']
                         for ip in ips:
-                            ip_ = IPv4Address(u"%s" % (ip,))
+                            ip_ = IPv4Address("%s" % (ip,))
                             for subnet in univention.admin.modules.lookup(subnet_module, None, lo, scope='sub', superordinate=superordinate, base=superordinate_dn, filter=''):
-                                if ip_ in IPv4Network(u"%(subnet)s/%(subnetmask)s" % subnet, strict=False):
+                                if ip_ in IPv4Network("%(subnet)s/%(subnetmask)s" % subnet, strict=False):
                                     print("  Subnet-based Settings:", file=self.stdout)
                                     ddict = get_policy(subnet.dn, self.stdout, policyOptions, policies_with_DN)
                                     print('', file=self.stdout)
@@ -1042,7 +1042,7 @@ class CLI(object):
 
 
 @overload
-def get_policy(  # noqa: E704
+def get_policy(
     dn,  # type: str
     stream,  # type: IO[str]
     policyOptions=None,  # type: Optional[Sequence[str]]
@@ -1052,7 +1052,7 @@ def get_policy(  # noqa: E704
 
 
 @overload
-def get_policy(  # noqa: E704
+def get_policy(
     dn,  # type: str
     stream,  # type: IO[str]
     policyOptions,  # type: Optional[Sequence[str]]
