@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -56,7 +55,6 @@ class UsersUserObjectProperties(GenericObjectProperties):
         'sambaLogonHours': SambaLogonHoursPropertyEncoder,
         'sambaRID': StringIntPropertyEncoder,
         'secretary': dn_list_property_encoder_for('users/user'),
-        'serviceprovider': dn_list_property_encoder_for('saml/serviceprovider'),
         'uidNumber': StringIntPropertyEncoder,
         'userexpiry': DatePropertyEncoder,
     }
