@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -104,25 +103,25 @@ The LDAP connection to use must be supplies as an argument to the UDM module fac
         # If it is a username, a machine connection is used to retrieve the DN it belongs to.
 """
 
+from __future__ import annotations
 
 from fnmatch import fnmatch
 from operator import itemgetter
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Type  # noqa: F401
+from typing import TYPE_CHECKING, Self
 
 from .exceptions import ApiVersionMustNotChange, ApiVersionNotSupported, NoApiVersionSet, NoObject
 from .plugins import Plugins
 
 
 if TYPE_CHECKING:
-    import univention.admin.uldap  # noqa: F401
-
-    from .base import BaseModule, BaseObject  # noqa: F401
+    import univention.admin.uldap
 
+    from .base import BaseModule, BaseObject
 
 _MODULES_PATH = 'univention.udm.modules'
 
 
-class UDM(object):
+class UDM:
     """
     Dynamic factory for creating :py:class:`BaseModule` objects::
 
@@ -135,10 +134,9 @@ class UDM(object):
             UDM.admin().version(2).obj_by_dn(dn)
     """
 
-    _module_object_cache = {}  # type: Dict[Tuple[str, int, int], BaseModule]
+    _module_object_cache: dict[tuple[str, int, int], BaseModule] = {}
 
-    def __init__(self, connection, api_version=None):
-        # type: (univention.admin.uldap.access, Optional[int]) -> None
+    def __init__(self, connection: univention.admin.uldap.access, api_version: int | None = None) -> None:
         """
         Use the provided connection.
 
@@ -147,13 +145,12 @@ class UDM(object):
                 specified version, can be set later using :py:meth:`version()`.
         """
         self.connection = connection
-        self._api_version = None  # type: Optional[int]
+        self._api_version: int | None = None
         if api_version is not None:
             self.version(api_version)
 
     @classmethod
-    def admin(cls):
-        # type: () -> UDM
+    def admin(cls) -> Self:
         """
         Use a cn=admin connection.
 
@@ -165,8 +162,7 @@ class UDM(object):
         return cls(connection)
 
     @classmethod
-    def machine(cls, prefer_local_connection=False):
-        # type: (bool) -> UDM
+    def machine(cls, prefer_local_connection: bool = False) -> Self:
         """
         Use a machine connection.
 
@@ -183,12 +179,12 @@ class UDM(object):
     @classmethod
     def credentials(
         cls,
-        identity,  # type: str
-        password,  # type: str
-        base=None,  # type: Optional[str]
-        server=None,  # type: Optional[str]
-        port=None,  # type: Optional[int]
-    ):  # type: (...) -> UDM
+        identity: str,
+        password: str,
+        base: str | None = None,
+        server: str | None = None,
+        port: int | None = None,
+    ) -> Self:
         """
         Use the provided credentials to open an LDAP connection.
 
@@ -207,8 +203,7 @@ class UDM(object):
         connection = LDAP_connection.get_credentials_connection(identity, password, base, server, port)
         return cls(connection)
 
-    def version(self, api_version):
-        # type: (int) -> UDM
+    def version(self, api_version: int) -> Self:
         """
         Set the version of the API that the UDM modules must support.
 
@@ -229,8 +224,7 @@ class UDM(object):
             raise ApiVersionMustNotChange()
         return self
 
-    def get(self, name):
-        # type: (str) -> BaseModule
+    def get(self, name: str) -> BaseModule:
         """
         Get an object of :py:class:`BaseModule` (or of a subclass) for UDM
         module `name`.
@@ -260,8 +254,7 @@ class UDM(object):
                 self._module_object_cache[key] = klass(name, self.connection, self.api_version)
         return self._module_object_cache[key]
 
-    def obj_by_dn(self, dn):
-        # type: (str) -> BaseObject
+    def obj_by_dn(self, dn: str) -> BaseObject:
         """
         Try to load an UDM object from LDAP. Guess the required UDM module
         from the ``univentionObjectType`` LDAP attribute of the LDAP object.
@@ -285,8 +278,7 @@ class UDM(object):
         return udm_module.get(dn)
 
     @property
-    def api_version(self):
-        # type: () -> int
+    def api_version(self) -> int:
         if self._api_version is None:
             raise NoApiVersionSet()
         return self._api_version
